﻿------------------------------------------------------------------
--ShowMaterials.lua
--Author: Soleya
--[[
Based on "Show Mottifs" by mra4nii  http://www.esoui.com/downloads/info298-ShowMotifs.html

Shows you the material types in your materials menu
]]
------------------------------------------------------------------

local ShowMaterials = ShowMaterials

-- where do we want to show our icons
local BACKPACK = ZO_PlayerInventoryBackpack
local BANK = ZO_PlayerBankBackpack
local GUILD_BANK = ZO_GuildBankBackpack
local DECONSTRUCTION = ZO_SmithingTopLevelDeconstructionPanelInventoryBackpack
local IMPROVEMENT = ZO_SmithingTopLevelImprovementPanelInventoryBackpack

local ShowMatSettings = nil

-- functions to manipulate tooltips for icons
local function AddTooltips(control, text)
	control:SetHandler("OnMouseEnter", function(self)
			ZO_Tooltips_ShowTextTooltip(self, TOP, text)
		end)
	control:SetHandler("OnMouseExit", function(self)
			ZO_Tooltips_HideTextTooltip()
		end)
end

local function RemoveTooltips(control)
	control:SetHandler("OnMouseEnter", nil)
	control:SetHandler("OnMouseExit", nil)
end

local function HandleTooltips(control, text)
	control:SetMouseEnabled(false)
	RemoveTooltips(control)
end

-- functions to create Material Type control, initially invisible
local function SetMaterial(MaterialControl)
	MaterialControl:SetHidden(true)
end

local function CreateMaterialControl(parent)
	local control = WINDOW_MANAGER:CreateControl(parent:GetName() .. "ShowMaterials_Materialstyle", parent, CT_TEXTURE)
	SetMaterial(control)

	return control
end

-- function checks if item crafting material
local function CheckMaterialID(bagId, slotIndex)
	local itemType = GetItemType(bagId, slotIndex)

	if (itemType ~= ITEMTYPE_ALCHEMY_BASE and itemType ~= ITEMTYPE_ARMOR_BOOSTER and itemType ~= ITEMTYPE_ARMOR_TRAIT and
		itemType ~= ITEMTYPE_BLACKSMITHING_BOOSTER and itemType ~= ITEMTYPE_BLACKSMITHING_MATERIAL and itemType ~= ITEMTYPE_BLACKSMITHING_RAW_MATERIAL and
		itemType ~= ITEMTYPE_CLOTHIER_BOOSTER and itemType ~= ITEMTYPE_CLOTHIER_MATERIAL and itemType ~= ITEMTYPE_CLOTHIER_RAW_MATERIAL and
		itemType ~= ITEMTYPE_ENCHANTING_RUNE_ASPECT and itemType ~= ITEMTYPE_ENCHANTING_RUNE_ESSENCE and itemType ~= ITEMTYPE_ENCHANTING_RUNE_POTENCY and 
		itemType ~= ITEMTYPE_ENCHANTMENT_BOOSTER and itemType ~= ITEMTYPE_FLAVORING and
		itemType ~= ITEMTYPE_GLYPH_ARMOR and itemType ~= ITEMTYPE_GLYPH_JEWELRY and itemType ~= ITEMTYPE_GLYPH_WEAPON and
		itemType ~= ITEMTYPE_INGREDIENT and itemType ~= ITEMTYPE_RAW_MATERIAL and itemType ~= ITEMTYPE_REAGENT and
		itemType ~= ITEMTYPE_STYLE_MATERIAL and itemType ~= ITEMTYPE_WEAPON_BOOSTER and itemType ~= ITEMTYPE_WEAPON_TRAIT and
		itemType ~= ITEMTYPE_WOODWORKING_BOOSTER and itemType ~= ITEMTYPE_WOODWORKING_MATERIAL and itemType ~= ITEMTYPE_WOODWORKING_RAW_MATERIAL) then
		return -1
	end

	if ( not ShowMatSettings:GetMaterial(itemType) ) then
		return 0
	end

	return itemType
end


-- function to add Material Type icon to inventory slot if none exist: set texture, tooltip text, color, size, position and make visible
local function AddMaterialIndicatorToSlot(control)
	local bagId = control.dataEntry.data.bagId
	local slotIndex = control.dataEntry.data.slotIndex
	
	local MaterialControl = control:GetNamedChild("ShowMaterials_Materialstyle")
	
	if ( not MaterialControl ) then
		MaterialControl = CreateMaterialControl(control)
	end
	local MaterialID = CheckMaterialID(bagId, slotIndex)
	if ( MaterialID and MaterialID < 0 ) then
		MaterialControl:SetHidden(true)
		return
	end

	local _,_,_,_,_,_,_,quality = GetItemInfo(bagId, slotIndex)
	MaterialControl:SetColor(255, 255, 255, 1)	

	HandleTooltips(MaterialControl, ShowMatSettings:GetMaterialName(MaterialID))
	MaterialControl:SetAnchor(CENTER, control, LEFT, 300 + ShowMatSettings:GetIconPosition())
	MaterialControl:SetDimensions(ShowMatSettings:GetMaterialTextureSize(), ShowMatSettings:GetMaterialTextureSize())
	MaterialControl:SetTexture(ShowMatSettings:GetMaterialTexture(MaterialID))
	MaterialControl:SetHidden(false)
	
end


-- function to add Material Type icons to inventory slots
local function AddMaterialIndicators(self)
	for _,v in pairs(self.activeControls) do
		AddMaterialIndicatorToSlot(v)
	end
end


-- function to hide the Material Type icons
local function ClearMyControls(self)
	local MaterialControl = nil
	
	for _,control in pairs(self.activeControls) do
		MaterialControl = control:GetNamedChild("ShowMaterials_Materialstyle")
		if ( MaterialControl ) then
			MaterialControl:SetHidden(true)
		end

	end

end

-- function to add incos to indicated <<BAG> if it's open
local function CheckNow(self)
	if ( #self.activeControls > 0 and not self:IsHidden() ) then
		if ( not self.isGrid ) then
			AddMaterialIndicators(self)
		else
			ClearMyControls(self)
		end
    end
end

-- function to check if none of <<BAG>> is opened
local function AreAllHidden()
	return BANK:IsHidden() and BACKPACK:IsHidden() and GUILD_BANK:IsHidden() and DECONSTRUCTION:IsHidden() and IMPROVEMENT:IsHidden()
end

-- instead of updating our bags each frame, let's update each 50ms only
local bufferTime = 50 --ms
local elapsedTime = 0
local function ShowMaterials_OnUpdate()
	elapsedTime = elapsedTime + GetFrameDeltaTimeMilliseconds()
	if ( elapsedTime < bufferTime ) then return end
	elapsedTime = 0

	if ( AreAllHidden() ) then return end

	CheckNow(BANK)
	CheckNow(BACKPACK)
	CheckNow(GUILD_BANK)
	CheckNow(DECONSTRUCTION)
	CheckNow(IMPROVEMENT)
end

-- add handler for update event, but only if some bag is open
local function ShowMaterials_InvUpdate( ... )
	if ( ShowMatSettings:IsActivated() and not AreAllHidden() ) then
		ShowMaterials_Controller:SetHandler("OnUpdate", ShowMaterials_OnUpdate)
	end
end

-- load add-on, register a handler for when inventory is updated(add/remove item)
local function ShowMaterials_Loaded(eventCode, addOnName)
	if ( addOnName ~= "ShowMaterials" ) then
        return
    end

	ShowMatSettings = ShowMaterials.ShowMaterialsSettings:New()

	EVENT_MANAGER:RegisterForEvent("ShowMaterials", EVENT_INVENTORY_SINGLE_SLOT_UPDATE, ShowMaterials_InvUpdate)
	ShowMaterials_Controller:SetHandler("OnUpdate", ShowMaterials_OnUpdate)
	
	EVENT_MANAGER:UnregisterForEvent("ShowMaterials", EVENT_ADD_ON_LOADED)
end

-- initialize add-on
local function ShowMaterials_Initialized()
	EVENT_MANAGER:RegisterForEvent("ShowMaterials", EVENT_ADD_ON_LOADED, ShowMaterials_Loaded)
end

ShowMaterials_Initialized()