local ShowMaterials = ShowMaterials

-- here we will keep our settings and will make a menu to change them
ShowMaterials.ShowMaterialsSettings = ZO_Object:Subclass()

local LAM = LibStub("LibAddonMenu-2.0")
local settings = nil

-- list of available themes
local TEXTURE_OPTIONS = { "Default", "Alphabetic", }

-- function to initialize our settings object
function ShowMaterials.ShowMaterialsSettings:New()
	local obj = ZO_Object.New(self)
	obj:Initialize()
	return obj
end

-- default settings if none found
function ShowMaterials.ShowMaterialsSettings:Initialize()
	local defaults = {
		smToggle = true,
		MatTextureSize = 32,
		textureName = "Default",
		position = 0,
	}

	settings = ZO_SavedVars:NewAccountWide("ShowMaterials_Settings", 2, nil, defaults)

    self:CreateOptionsMenu()
end

-- function to check if module is activated
function ShowMaterials.ShowMaterialsSettings:IsActivated()
	return settings.smToggle

end

-- function checks if we have necessary dates for Material Type <<MaterialID>>
function ShowMaterials.ShowMaterialsSettings:GetMaterial(MaterialID)
	if ( ShowMaterials.TYPE_TEXTURES[settings.textureName][MaterialID] and ShowMaterials.TYPE_TEXTURES[settings.textureName][MaterialID].texture ) then
		return true
	else
		return false
	end
end

function ShowMaterials.ShowMaterialsSettings:GetMaterialTextureSize()
	return settings.MatTextureSize
end

-- function returns path to icon texture for Material Type <<MaterialID>>
function ShowMaterials.ShowMaterialsSettings:GetMaterialTexture(MaterialID)
	return ShowMaterials.TYPE_TEXTURES[settings.textureName][MaterialID].texture
end

-- function returns name of Material Type based on in-game strings
function ShowMaterials.ShowMaterialsSettings:GetMaterialName(TextureTypeID)
	return GetString(_G['SI_TYPE' .. TextureTypeID])
end

function ShowMaterials.ShowMaterialsSettings:GetMatTextureSize()
	return settings.MatTextureSize
end

-- function returns icon size for Material Type icon
function ShowMaterials.ShowMaterialsSettings:GetIconPosition()
	return settings.position
end

-- function to check client locale
function ShowMaterials.ShowMaterialsSettings:GetLang()
	local lang = GetCVar("language.2")
	if ( lang == "de" or lang == "en" or lang == "fr" ) then
		return lang
	end
	return "en"
end

-- function to create settings menu. It uses LibAddonMenu
function ShowMaterials.ShowMaterialsSettings:CreateOptionsMenu()

	local phrases = ShowMotifs.LOCALES[self:GetLang()].phrases

	local panel = {
		type = "panel",
		name = "Show Materials",
		displayName = "Show Materials Settings",
		author = "|cFF00FFSoleya|r",
		version = "1.6.0",
		slashCommand = "/showmaterials",
		registerForRefresh = true,
		registerForDefaults = true,
	}

	local options = {
		[1] = {
			type = "dropdown",
			name = phrases.ICON_THEME,
			tooltip = phrases.ICON_THEME_TOOLTIP,
			choices = TEXTURE_OPTIONS,
			getFunc = function() return settings.textureName end,
			setFunc = function(value)
						settings.textureName = value
						icon:SetTexture(ShowMotifs.STYLES_TEXTURES[settings.textureName][ITEMSTYLE_RACIAL_HIGH_ELF].texture)
						if ( settings.textureName == "Materials" ) then settings.ColorIcon = false end
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
					end,
			reference = "ShowMaterials_ShowMaterialsSettingsPanel_Icon_Dropdown",
			default = TEXTURE_OPTIONS[1],
		},

		[2] = {
			type = "slider",
			name = phrases.ICON_SIZE,
			tooltip = phrases.ICON_SIZE_TOOLTIP,
			min = 16,
			max = 64,
			step = 4,
			getFunc = function() return settings.MaterialTextureSize end,
			setFunc = function( value )
				settings.MaterialTextureSize = value
				icon:SetDimensions(settings.MaterialTextureSize, settings.MaterialTextureSize)
				ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = 32,
		},
		[3] = {
			type = "slider",
			name = phrases.ICON_POSITION,
			tooltip = phrases.ICON_POSITION_TOOLTIP,
			min = -150,
			max = 150,
			step = 1,
			getFunc = function() return settings.position end,
			setFunc = function( value )
				settings.position = value
				ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = 0,
		},
	}

	LAM:RegisterAddonPanel("ShowMaterialsPanel", panel)
	LAM:RegisterOptionControls("ShowMaterialsPanel", options)

end

